@@ -1,4 +1,4 @@
-/* $Id: xfce-i18n.c 27824 2008-09-11 18:35:07Z kelnos $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * Copyright (c) 2004      Jasper Huijsman <jasper@xfce.org>
@@ -27,6 +27,9 @@
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
 #endif
+#ifdef HAVE_LIBINTL_H
+#include <libintl.h>
+#endif
 #ifdef HAVE_LOCALE_H
 #include <locale.h>
 #endif
